@@ -2,7 +2,7 @@
 
 package Git::Hooks::CheckJira;
 # ABSTRACT: Git::Hooks plugin which requires citation of JIRA issues in commit messages
-$Git::Hooks::CheckJira::VERSION = '1.6.11';
+$Git::Hooks::CheckJira::VERSION = '1.6.12';
 use 5.010;
 use utf8;
 use strict;
@@ -244,12 +244,17 @@ sub _check_jira_keys {          ## no critic (ProhibitExcessComplexity)
                     and ++$errors
                         and next KEY;
 
-            my $assignee = $issue->{fields}{assignee}{name};
-
-            $user eq $assignee
-                or $git->error($PKG, "issue $key should be assigned to '$user', not '$assignee'")
-                    and ++$errors
-                        and next KEY;
+            if (my $assignee = $issue->{fields}{assignee}) {
+                my $name = $assignee->{name};
+                $user eq $name
+                    or $git->error($PKG, "issue $key should be assigned to '$user', not '$name'")
+                        and ++$errors
+                            and next KEY;
+            } else {
+                $git->error($PKG, "issue $key should be assigned to '$user', but it's unassigned");
+                ++$errors;
+                next KEY;
+            }
         }
 
         push @issues, $issue;
@@ -375,7 +380,7 @@ Git::Hooks::CheckJira - Git::Hooks plugin which requires citation of JIRA issues
 
 =head1 VERSION
 
-version 1.6.11
+version 1.6.12
 
 =head1 DESCRIPTION
 
