@@ -1,6 +1,6 @@
 package Git::More;
 # ABSTRACT: A Git extension with some goodies for hook developers
-$Git::More::VERSION = '1.6.11';
+$Git::More::VERSION = '1.6.12';
 use strict;
 use warnings;
 
@@ -120,11 +120,13 @@ sub get_commit {
         '--no-walk',
         # See 'git help rev-list' to understand the --pretty argument
         '--pretty=format:%H%n%T%n%P%n%aN%n%aE%n%ai%n%cN%n%cE%n%ci%n%s%n%n%b%x00',
+        '--encoding=UTF-8',
         $commit,
     );
 
     my $commit_hash;
     while (<$pipe>) {
+            chomp;
             my %commit;
             @commit{qw/header commit tree parent
                        author_name author_email author_date
@@ -535,7 +537,7 @@ Git::More - A Git extension with some goodies for hook developers
 
 =head1 VERSION
 
-version 1.6.11
+version 1.6.12
 
 =head1 SYNOPSIS
 
@@ -664,7 +666,7 @@ get rid of any value kept in the SECTION's cache.
 =head2 get_commit COMMIT
 
 This method returns a hash representing COMMIT. It obtains this information
-by invoking C<git rev-list --no-walk COMMIT>.
+by invoking C<git rev-list --no-walk --encoding=UTF-8 COMMIT>.
 
 The returned hash has the following structure (the codes are explained in
 the C<git help rev-list> document):
@@ -682,6 +684,8 @@ the C<git help rev-list> document):
         body            => %B:  raw body (aka commit message)
     }
 
+All character data is UTF-8 encoded.
+
 =head2 get_commits OLDCOMMIT NEWCOMMIT
 
 This method returns a list of hashes representing every commit
