@@ -1,4 +1,5 @@
 ## no critic (RequireExplicitPackage)
+## no critic (ErrorHandling::RequireCarping)
 use 5.010;
 use strict;
 use warnings;
@@ -16,7 +17,11 @@ local $ENV{LC_ALL} = 'C';
 # otherwise the author runs the risk of messing with its local
 # Git::Hooks git repository.
 
-our $T = Path::Tiny->tempdir(TEMPLATE => 'githooks.XXXXX', TMPDIR => 1, CLEANUP => $ENV{REPO_CLEANUP} || 1);
+our $T = Path::Tiny->tempdir(
+    TEMPLATE => 'githooks.XXXXX',
+    TMPDIR   => 1,
+    CLEANUP  => exists $ENV{REPO_CLEANUP} ? $ENV{REPO_CLEANUP} : 1,
+);
 use Cwd; my $cwd = path(cwd);
 chdir $T or die "Can't chdir $T: $!";
 END { chdir '/' }
@@ -48,38 +53,38 @@ sub install_hooks {
     my $hook_pl   = $hooks_dir->child('hook.pl');
     {
         ## no critic (RequireBriefOpen)
-	open my $fh, '>', $hook_pl or BAIL_OUT("Can't create $hook_pl: $!");
-	state $debug = $ENV{DBG} ? '-d' : '';
-	state $bliblib = $cwd->child('blib', 'lib');
-	print $fh <<"EOF";
+        open my $fh, '>', $hook_pl or BAIL_OUT("Can't create $hook_pl: $!");
+        state $debug = $ENV{DBG} ? '-d' : '';
+        state $bliblib = $cwd->child('blib', 'lib');
+        print $fh <<"EOF";
 #!$Config{perlpath} $debug
 use strict;
 use warnings;
 use lib '$bliblib';
 EOF
 
-	state $pathsep = $^O eq 'MSWin32' ? ';' : ':';
-	if (defined $ENV{PERL5LIB} and length $ENV{PERL5LIB}) {
-	    foreach my $path (reverse split "$pathsep", $ENV{PERL5LIB}) {
-		say $fh "use lib '$path';" if $path;
-	    }
-	}
+        state $pathsep = $^O eq 'MSWin32' ? ';' : ':';
+        if (defined $ENV{PERL5LIB} and length $ENV{PERL5LIB}) {
+            foreach my $path (reverse split "$pathsep", $ENV{PERL5LIB}) {
+                say $fh "use lib '$path';" if $path;
+            }
+        }
 
-	print $fh <<'EOF';
+        print $fh <<'EOF';
 use Git::Hooks;
 EOF
 
-	print $fh $extra_perl if defined $extra_perl;
+        print $fh $extra_perl if defined $extra_perl;
 
         # Not all hooks defined the GIT_DIR environment variable
         # (e.g., pre-rebase doesn't).
-	print $fh <<"EOF";
+        print $fh <<"EOF";
 \$ENV{GIT_DIR}    = '.git' unless exists \$ENV{GIT_DIR};
 \$ENV{GIT_CONFIG} = "\$ENV{GIT_DIR}/config";
 EOF
 
         # Reset HOME to avoid reading ~/.gitconfig
-	print $fh <<"EOF";
+        print $fh <<"EOF";
 \$ENV{HOME}       = '';
 EOF
 
@@ -95,18 +100,18 @@ run_hook(\$0, \@ARGV);
 EOF
         }
     }
-	    chmod 0755 => $hook_pl;
+    chmod 0755 => $hook_pl;
 
     @hooks = qw/ applypatch-msg pre-applypatch post-applypatch
-		 pre-commit prepare-commit-msg commit-msg
-		 post-commit pre-rebase post-checkout post-merge
-		 pre-receive update post-receive post-update
-		 pre-auto-gc post-rewrite /
-                     unless @hooks;
+        pre-commit prepare-commit-msg commit-msg
+        post-commit pre-rebase post-checkout post-merge
+        pre-receive update post-receive post-update
+        pre-auto-gc post-rewrite /
+            unless @hooks;
 
     foreach my $hook (@hooks) {
-	my $hookfile = $hooks_dir->child($hook);
-	if ($^O eq 'MSWin32') {
+        my $hookfile = $hooks_dir->child($hook);
+        if ($^O eq 'MSWin32') {
             (my $perl = $^X) =~ tr:\\:/:;
             $hook_pl =~ tr:\\:/:;
             my $d = $ENV{DBG} ? '-d' : '';
@@ -116,8 +121,8 @@ $perl $d $hook_pl $hook \"\$@\"
 EOF
             path($hookfile)->spew($script)
                 or BAIL_OUT("can't path('$hookfile')->spew('$script')\n");
-	    chmod 0755 => $hookfile;
-	} else {
+            chmod 0755 => $hookfile;
+        } else {
             symlink 'hook.pl', $hookfile
                 or BAIL_OUT("can't symlink '$hooks_dir', '$hook': $!");
         }
@@ -136,46 +141,46 @@ sub new_repos {
 
     mkdir $repodir, 0777 or BAIL_OUT("can't mkdir $repodir: $!");
     {
-	open my $fh, '>', $filename or die BAIL_OUT("can't open $filename: $!");
-	say $fh "first line";
+        open my $fh, '>', $filename or die BAIL_OUT("can't open $filename: $!");
+        say $fh "first line";
         close $fh;
     }
 
     return try {
-	my ($repo, $clone);
+        my ($repo, $clone);
 
         {
-	    # It would be easier to pass a directory argument to
-	    # git-init but it started to accept it only on v1.6.5. To
-	    # support previous gits we chdir to $repodir to avoid the
-	    # need to pass the argument. Then we have to go back to
-	    # where we were.
+            # It would be easier to pass a directory argument to
+            # git-init but it started to accept it only on v1.6.5. To
+            # support previous gits we chdir to $repodir to avoid the
+            # need to pass the argument. Then we have to go back to
+            # where we were.
             my $dir = pushd($repodir);
             Git::command(qw/init -q/, "--template=$tmpldir");
 
-	    $repo = Git::More->repository(Directory => '.');
+            $repo = Git::More->repository(Directory => '.');
 
-	    $repo->command(config => 'user.email', 'myself@example.com');
-	    $repo->command(config => 'user.name',  'My Self');
-	}
+            $repo->command(config => 'user.email', 'myself@example.com');
+            $repo->command(config => 'user.name',  'My Self');
+        }
 
         Git::command(
             [qw/clone -q --bare --no-hardlinks/, "--template=$tmpldir", $repodir, $clonedir],
             { STDERR => 0 },    # do not complain about cloning an empty repo
         );
 
-	$clone = Git::More->repository(Repository => $clonedir);
+        $clone = Git::More->repository(Repository => $clonedir);
 
         $repo->command(qw/remote add clone/, $clonedir);
 
-	return ($repo, $filename, $clone, $T);
+        return ($repo, $filename, $clone, $T);
     } otherwise {
         my $E = shift;
         # The BAIL_OUT function can't show a message with newlines
         # inside. So, we have to make sure to get rid of any.
         $E =~ s/\n//g;
         local $, = ':';
-	BAIL_OUT("Error setting up repos for test: Exception='$E'; CWD=$T; git-version=$git_version; \@INC=(@INC).\n");
+        BAIL_OUT("Error setting up repos for test: Exception='$E'; CWD=$T; git-version=$git_version; \@INC=(@INC).\n");
     };
 }
 
@@ -208,10 +213,10 @@ sub test_command {
     my ($stdout, $exception);
 
     try {
-	$stdout = $git->command($cmd, @args);
-	$stdout = '' unless defined $stdout;
+        $stdout = $git->command($cmd, @args);
+        $stdout = '' unless defined $stdout;
     } otherwise {
-        $exception = "$_[0]";	# stringify the exception
+        $exception = "$_[0]"; # stringify the exception
     };
 
     # Redirect STDERR back to its original value
@@ -222,9 +227,9 @@ sub test_command {
     my $stderr = path('stderr')->slurp;
 
     if (defined $exception) {
-	return (0, $?, $exception, $stderr);
+        return (0, $?, $exception, $stderr);
     } else {
-	return (1, 0, $stdout, $stderr);
+        return (1, 0, $stdout, $stderr);
     }
 }
 
@@ -232,10 +237,10 @@ sub test_ok {
     my ($testname, @args) = @_;
     my ($ok, $exit, $stdout, $stderr) = test_command(@args);
     if ($ok) {
-	pass($testname);
+        pass($testname);
     } else {
-	fail($testname);
-	diag(" exit=$exit\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
+        fail($testname);
+        diag(" exit=$exit\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
     }
     return $ok;
 }
@@ -251,8 +256,8 @@ sub test_ok_match {
             diag(" did not match regex ($regex)\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
         }
     } else {
-	fail($testname);
-	diag(" exit=$exit\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
+        fail($testname);
+        diag(" exit=$exit\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
     }
     return $ok;
 }
@@ -261,10 +266,10 @@ sub test_nok {
     my ($testname, @args) = @_;
     my ($ok, $exit, $stdout, $stderr) = test_command(@args);
     if ($ok) {
-	fail($testname);
-	diag(" succeeded without intention\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
+        fail($testname);
+        diag(" succeeded without intention\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
     } else {
-	pass($testname);
+        pass($testname);
     }
     return !$ok;
 }
@@ -273,16 +278,16 @@ sub test_nok_match {
     my ($testname, $regex, @args) = @_;
     my ($ok, $exit, $stdout, $stderr) = test_command(@args);
     if ($ok) {
-	fail($testname);
-	diag(" succeeded without intention\n exit=$exit\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
-	return 0;
+        fail($testname);
+        diag(" succeeded without intention\n exit=$exit\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
+        return 0;
     } elsif ($stdout =~ $regex || $stderr =~ $regex) {
-	pass($testname);
-	return 1;
+        pass($testname);
+        return 1;
     } else {
-	fail($testname);
-	diag(" did not match regex ($regex)\n exit=$exit\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
-	return 0;
+        fail($testname);
+        diag(" did not match regex ($regex)\n exit=$exit\n stdout=$stdout\n stderr=$stderr\n git-version=$git_version\n");
+        return 0;
     }
 }
 
